@@ -46,7 +46,7 @@ any other package maintainer - I want to ensure the package is as accessible and
 useful as possible.
      
 """
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 __package__ = 'amos'
 
@@ -70,8 +70,6 @@ from .observe.module import *
 from .observe.package import *
 from .observe.registries import *
 from .observe.traits import *
-from .project.settings import *
-from .project.filing import *
 from .repair.convert import *
 from .repair.modify import *
 from .repair.validate import *
